@@ -25,40 +25,35 @@
 #include <QStringList>
 #include <QTimer>
 
+class QNetworkConfigurationManager;
 class KStatusNotifierItem;
 
 class DiscoverNotifier : public QObject
 {
 Q_OBJECT
 Q_PROPERTY(QStringList modules READ loadedModules CONSTANT)
-Q_PROPERTY(bool isSystemUpToDate READ isSystemUpToDate NOTIFY updatesChanged)
-Q_PROPERTY(QString iconName READ iconName NOTIFY updatesChanged)
-Q_PROPERTY(QString message READ message NOTIFY updatesChanged)
-Q_PROPERTY(QString extendedMessage READ extendedMessage NOTIFY updatesChanged)
-Q_PROPERTY(State state READ state NOTIFY updatesChanged)
+Q_PROPERTY(QString iconName READ iconName NOTIFY stateChanged)
+Q_PROPERTY(QString message READ message NOTIFY stateChanged)
+Q_PROPERTY(State state READ state NOTIFY stateChanged)
 Q_PROPERTY(bool needsReboot READ needsReboot NOTIFY needsRebootChanged)
 public:
     enum State {
         NoUpdates,
         NormalUpdates,
         SecurityUpdates,
-        RebootRequired
+        RebootRequired,
+        Offline,
     };
     Q_ENUM(State)
 
     explicit DiscoverNotifier(QObject* parent = nullptr);
     ~DiscoverNotifier() override;
 
-    bool isSystemUpToDate() const;
-
     State state() const;
     QString iconName() const;
     QString message() const;
-    QString extendedMessage() const;
-    /*** @returns count of normal updates only **/
-    uint updatesCount() const;
-    /*** @returns count of security updates only **/
-    uint securityUpdatesCount() const;
+    bool hasUpdates() const { return m_hasUpdates; }
+    bool hasSecurityUpdates() const { return m_hasSecurityUpdates; }
 
     QStringList loadedModules() const;
     bool needsReboot() const { return m_needsReboot; }
@@ -73,7 +68,7 @@ public Q_SLOTS:
     void foundUpgradeAction(UpgradeAction* action);
 
 Q_SIGNALS:
-    void updatesChanged();
+    void stateChanged();
     bool needsRebootChanged(bool needsReboot);
     void newUpgradeAction(UpgradeAction* action);
 
@@ -82,11 +77,12 @@ private:
     void updateStatusNotifier();
 
     QList<BackendNotifierModule*> m_backends;
-    bool m_verbose;
+    bool m_verbose = false;
     QTimer m_timer;
-    uint m_securityCount = 0;
-    uint m_count = 0;
+    bool m_hasSecurityUpdates = false;
+    bool m_hasUpdates = false;
     bool m_needsReboot = false;
+    QNetworkConfigurationManager* const m_manager;
 };
 
 #endif //ABSTRACTKDEDMODULE_H
